summaryrefslogtreecommitdiff
path: root/expt_0510.cu
diff options
context:
space:
mode:
authorKunoiSayami <[email protected]>2023-07-02 21:53:47 +0800
committerKunoiSayami <[email protected]>2023-07-02 21:53:47 +0800
commitc71e687de86691c0149804ef10721ac9c230ab9e (patch)
treec5edef26ed08eeea4c4479016faea2dbcca7430c /expt_0510.cu
parent0b09bc40d295e7b383f2e5c8ddba255f0ac680ca (diff)
refactor: Change basic function name
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_0510.cu')
-rw-r--r--expt_0510.cu12
1 files changed, 6 insertions, 6 deletions
diff --git a/expt_0510.cu b/expt_0510.cu
index eca1b92..19d1fb0 100644
--- a/expt_0510.cu
+++ b/expt_0510.cu
@@ -61,10 +61,10 @@ __global__ void kernel(unsigned long step, const double slice_size) {
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
// printf("%d\n", tid);
- auto _index = (int)(custom_sort.sample_cdf_custom_version(
- cudaSampleItem, cudaPopulationItem[tid]) /
- slice_size) -
- 1;
+ auto _index =
+ (int)(custom_sort.cdf(cudaSampleItem, cudaPopulationItem[tid]) /
+ slice_size) -
+ 1;
// cdf_result[index] = true;
}
}
@@ -74,8 +74,8 @@ __global__ void kernel2(unsigned long step, const double slice_size) {
for (int i = 0; i < step; i++) {
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
auto _index =
- (int)(FactorySort::sample_cdf(cudaNormalSampleItem, cuda_sample_length,
- cudaPopulationItem[tid]) /
+ (int)(FactorySort::cdf(cudaNormalSampleItem, cuda_sample_length,
+ cudaPopulationItem[tid]) /
slice_size) -
1;
// cdf_result[index] = true;